@@ -26,13 +26,12 @@
 
 #include <kaboutdata.h>
 #include <kconfig.h>
-#include <kcomponentdata.h>
 #include <kdebug.h>
-#include <kinputdialog.h>
-#include <klocale.h>
+#include <qinputdialog.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
 #include <knotification.h>
-#include <kactionmenu.h>
+#include <KActionMenu>
 
 #include <kopeteuiglobal.h>
 #include <kopetecontactlist.h>
@@ -78,15 +77,15 @@ GroupWiseAccount::GroupWiseAccount( GroupWiseProtocol *parent, const QString& ac
 	QObject::connect( Kopete::ContactList::self(), SIGNAL(groupRemoved(Kopete::Group*)),
 			SLOT(slotKopeteGroupRemoved(Kopete::Group*)) );
 
-//		m_actionBlock = new KAction( KIcon( "msn_blocked" ), label, 0, "actionBlock" );
+//		m_actionBlock = new QAction( QIcon::fromTheme(QStringLiteral("msn_blocked")), label, 0, "actionBlock" );
 //		QObject::connect( m_actionBlock, SIGNAL(triggered(bool)), SLOT(slotBlock()) );
-	m_actionAutoReply = new KAction ( i18n( "&Set Auto-Reply..." ), 0 );
+    m_actionAutoReply = new QAction ( i18n( "&Set Auto-Reply..." ), 0 );
 	QObject::connect( m_actionAutoReply, SIGNAL(triggered(bool)),
 			SLOT(slotSetAutoReply()) );
-	m_actionJoinChatRoom = new KAction ( i18n( "&Join Channel..." ), 0 );
+    m_actionJoinChatRoom = new QAction ( i18n( "&Join Channel..." ), 0 );
 	QObject::connect( m_actionJoinChatRoom, SIGNAL(triggered(bool)),
 										 SLOT(slotJoinChatRoom()) );
-	m_actionManagePrivacy = new KAction ( i18n( "&Manage Privacy..." ), 0 );
+    m_actionManagePrivacy = new QAction ( i18n( "&Manage Privacy..." ), 0 );
 	QObject::connect( m_actionManagePrivacy, SIGNAL(triggered(bool)),
 										 SLOT(slotPrivacy()) );
 			
@@ -116,7 +115,7 @@ void GroupWiseAccount::fillActionMenu( KActionMenu *actionMenu )
 	actionMenu->addAction( m_actionJoinChatRoom );
 	/* Used for debugging */
 	/*
-	theActionMenu->insert( new KAction ( "Test rtfize()", QString(), 0, this,
+    theActionMenu->insert( new QAction ( "Test rtfize()", QString(), 0, this,
 		SLOT(slotTestRTFize()), this,
 		"actionTestRTFize") );
 	*/
@@ -153,7 +152,7 @@ GroupWiseChatSession * GroupWiseAccount::chatSession( Kopete::ContactPtrList oth
 			chatSession = findChatSessionByGuid( guid );
 			if ( chatSession )
 			{
-					kDebug() << " found a message manager by GUID: " << guid;
+					qDebug() << " found a message manager by GUID: " << guid;
 					break;
 			}
 		}
@@ -162,7 +161,7 @@ GroupWiseChatSession * GroupWiseAccount::chatSession( Kopete::ContactPtrList oth
 				Kopete::ChatSessionManager::self()->findChatSession( myself(), others, protocol() ) );
 		if ( chatSession )
 		{
-			kDebug() << " found a message manager by members with GUID: " << chatSession->guid();
+			qDebug() << " found a message manager by members with GUID: " << chatSession->guid();
 			// re-add the returning contact(s) (very likely only one) to the chat
 			foreach ( Kopete::Contact * returningContact, others )
 				chatSession->joined( static_cast<GroupWiseContact *>( returningContact ) );
@@ -175,7 +174,7 @@ GroupWiseChatSession * GroupWiseAccount::chatSession( Kopete::ContactPtrList oth
 		if ( canCreate )
 		{
 			chatSession = new GroupWiseChatSession( myself(), others, protocol(), guid );
-			kDebug() <<
+			qDebug() <<
 					" created a new message manager with GUID: " << chatSession->guid() << endl;
 			m_chatSessions.append( chatSession );
 			// listen for the message manager telling us that the user
@@ -184,7 +183,7 @@ GroupWiseChatSession * GroupWiseAccount::chatSession( Kopete::ContactPtrList oth
 							SLOT(slotLeavingConference(GroupWiseChatSession*)) );
 			break;
 		}
-		//kDebug() <<
+		//qDebug() <<
 		//		" no message manager available." << endl;
 	}
 	while ( 0 );
@@ -251,7 +250,7 @@ void GroupWiseAccount::connectWithPassword( const QString &password )
 
 	if (!sslPossible)
 	{
-		KMessageBox::queuedMessageBox(Kopete::UI::Global::mainWidget (), KMessageBox::Error,
+		KMessageBox::error(Kopete::UI::Global::mainWidget (),
 							i18n ("SSL support could not be initialized for account %1. This is most likely because the QCA TLS plugin is not installed on your system.", 
 							myself()->contactId()),
 							i18n ("GroupWise SSL Error"));
@@ -349,15 +348,15 @@ void GroupWiseAccount::connectWithPassword( const QString &password )
 
 	struct utsname utsBuf;
 	uname (&utsBuf);
-	m_client->setClientName ("Kopete");
-	m_client->setClientVersion ( KGlobal::mainComponent().aboutData()->version () );
-	m_client->setOSName (QString ("%1 %2").arg (utsBuf.sysname, 1).arg (utsBuf.release, 2));
+	m_client->setClientName (QStringLiteral("Kopete"));
+	m_client->setClientVersion ( KAboutData::applicationData().version () );
+	m_client->setOSName (QStringLiteral ("%1 %2").arg (utsBuf.sysname, 1).arg (utsBuf.release, 2));
 
 	kDebug () << "Connecting to GroupWise server " << server() << ':' << port();
 
 	NovellDN dn;
-	dn.dn = "maeuschen";
-	dn.server = "reiser.suse.de";
+	dn.dn = QStringLiteral("maeuschen");
+	dn.server = QStringLiteral("reiser.suse.de");
 	m_serverListModel = new GWContactList( this );
 	myself()->setOnlineStatus( protocol()->groupwiseConnecting );
 	m_client->connectToServer( m_clientStream, dn, true );
@@ -366,7 +365,7 @@ void GroupWiseAccount::connectWithPassword( const QString &password )
 
 void GroupWiseAccount::slotMessageSendingFailed()
 {
-	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry,
+	KMessageBox::sorry( Kopete::UI::Global::mainWidget(),
 				i18nc("Message Sending Failed using the named local account", "Kopete was not able to send the last message sent on account '%1'.\nIf possible, please send the console output from Kopete to <wstephenson@novell.com> for analysis.", accountId() ) , i18nc("message sending failed using the named local account", "Unable to Send Message on Account '%1'", accountId() ) );
 }
 
@@ -377,13 +376,13 @@ void GroupWiseAccount::setOnlineStatus( const Kopete::OnlineStatus& status, cons
 			|| status == protocol()->groupwiseConnecting
 			|| status == protocol()->groupwiseInvalid )
 	{
-		kDebug() << " called with invalid status \"" 
+		qDebug() << " called with invalid status \"" 
 				<< status.description() << "\"" << endl;
 	}
 	// going offline
 	else if ( status == protocol()->groupwiseOffline )
 	{
-		kDebug() << " DISCONNECTING";
+		qDebug() << " DISCONNECTING";
 		disconnect();
 	}
 	// changing status
@@ -419,7 +418,7 @@ void GroupWiseAccount::disconnect ()
 
 void GroupWiseAccount::disconnect( Kopete::Account::DisconnectReason reason )
 {
-	kDebug() ;
+	qDebug() ;
 
 	if( isConnected () )
 	{
@@ -441,7 +440,7 @@ void GroupWiseAccount::disconnect( Kopete::Account::DisconnectReason reason )
 	myself()->setOnlineStatus( GroupWiseProtocol::protocol()->groupwiseOffline );
 
 	disconnected( reason );
-	kDebug() << "Disconnected.";
+	qDebug() << "Disconnected.";
 }
 
 void GroupWiseAccount::cleanup()
@@ -486,7 +485,7 @@ void GroupWiseAccount::slotLoggedIn()
 	if ( initialStatus() != Kopete::OnlineStatus(Kopete::OnlineStatus::Online) &&
 		( ( GroupWise::Status )initialStatus().internalStatus() != GroupWise::Unknown ) )
 	{
-		kDebug() << "Initial status is not online, setting status to " << initialStatus().internalStatus();
+		qDebug() << "Initial status is not online, setting status to " << initialStatus().internalStatus();
 		m_client->setStatus( ( GroupWise::Status )initialStatus().internalStatus(), m_initialReason, configGroup()->readEntry( "AutoReply", "" ) );
 	}
 }
@@ -523,13 +522,13 @@ void GroupWiseAccount::reconcileOfflineChanges()
 		it.next();
 
 		GroupWiseContact * c = static_cast< GroupWiseContact *>( it.value() );
-		kDebug() << "  reconciling changes for: '" << c->contactId() << "'";
+		qDebug() << "  reconciling changes for: '" << c->contactId() << "'";
 		GWContactInstanceList instances = m_serverListModel->instancesWithDn( c->dn() );
 		QListIterator<Kopete::Group *> grpIt( c->metaContact()->groups() );
 		while ( grpIt.hasNext() )
 		{
 			Kopete::Group * grp = grpIt.next();
-			kDebug() << "    looking at local group membership: '" << grp->displayName() << "'";
+			qDebug() << "    looking at local group membership: '" << grp->displayName() << "'";
 			bool found = false;
 			QMutableListIterator<GWContactInstance*> instIt( instances );
 			while ( instIt.hasNext() )
@@ -544,7 +543,7 @@ void GroupWiseAccount::reconcileOfflineChanges()
 						continue;
 				}
 				GWFolder * folder = qobject_cast<GWFolder*>( instIt.value()->parent() );
-				kDebug() << "      local stored groupId #" << groupId.toInt() << ", remote instance groupId #" << folder->id;
+				qDebug() << "      local stored groupId #" << groupId.toInt() << ", remote instance groupId #" << folder->id;
 				if ( folder->id == ( unsigned int )groupId.toInt() )
 				{
 					found = true;
@@ -558,13 +557,13 @@ void GroupWiseAccount::reconcileOfflineChanges()
 				{
 					if ( c->metaContact()->groups().count() == 1 )
 					{
-						kDebug() << "local contact instance " << c->dn() << " not found on server side list, no matches with contact instances' groups on server, deleting metacontact with only this contact, in one group" << c->metaContact()->displayName();
+						qDebug() << "local contact instance " << c->dn() << " not found on server side list, no matches with contact instances' groups on server, deleting metacontact with only this contact, in one group" << c->metaContact()->displayName();
 						Kopete::ContactList::self()->removeMetaContact( c->metaContact() );
 						break;
 					}
 					else
 					{
-						kDebug() << "contact instance " << c->dn() << " not found, removing metacontact " << c->metaContact()->displayName() << " from group " << grp->displayName();
+						qDebug() << "contact instance " << c->dn() << " not found, removing metacontact " << c->metaContact()->displayName() << " from group " << grp->displayName();
 						c->metaContact()->removeFromGroup( grp );
 					}
 				}
@@ -572,12 +571,12 @@ void GroupWiseAccount::reconcileOfflineChanges()
 				{
 					if ( c->metaContact()->groups().count() == 1 )
 					{
-						kDebug() << "contact instance " << c->dn() << " not found, removing contact " << c->metaContact()->displayName() << " from metacontact with other contacts ";
+						qDebug() << "contact instance " << c->dn() << " not found, removing contact " << c->metaContact()->displayName() << " from metacontact with other contacts ";
 						c->deleteLater();
 						break;
 					}
 					else
-						kDebug() << "metacontact " << c->metaContact()->displayName( ) << "has multiple children and group membership, and contact " << c->dn() << " was removed from one group on the server.";
+						qDebug() << "metacontact " << c->metaContact()->displayName( ) << "has multiple children and group membership, and contact " << c->dn() << " was removed from one group on the server.";
 						conflicts = true;
 				}
 			} // 
@@ -637,11 +636,11 @@ void GroupWiseAccount::slotKopeteGroupRemoved( Kopete::Group * group )
 		QString objectIdString = group->pluginData( protocol(), accountId() + " objectId" );
 		if ( !objectIdString.isEmpty() )
 		{
-			kDebug() << "deleting folder with objectId: " << objectIdString;
+			qDebug() << "deleting folder with objectId: " << objectIdString;
 			int objectId = objectIdString.toInt();
 			if ( objectId == 0 )
 			{
-				kDebug() << "deleted folder " << group->displayName() << " has root folder objectId 0!";
+				qDebug() << "deleted folder " << group->displayName() << " has root folder objectId 0!";
 				return;
 			}
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
@@ -657,7 +656,7 @@ void GroupWiseAccount::slotKopeteGroupRemoved( Kopete::Group * group )
 void GroupWiseAccount::slotConnError()
 {
 	kDebug () ;
-	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry,
+	KMessageBox::sorry( Kopete::UI::Global::mainWidget(),
 				i18nc( "Error shown when connecting failed", "Kopete was not able to connect to the GroupWise Messenger server for account '%1'.\nPlease check your server and port settings and try again.", accountId() ) , i18n ("Unable to Connect '%1'", accountId() ) );
 
 	disconnect();
@@ -734,15 +733,15 @@ int GroupWiseAccount::handleTLSWarning ( QCA::TLS::IdentityResult identityResult
 			break;
 		case QCA::TLS::HostMismatch:
 			idString = i18n("The host name does not match the one in the certificate.");
-			idCode   = "HostMismatch";
+			idCode   = QStringLiteral("HostMismatch");
 			break;
 		case QCA::TLS::InvalidCertificate:
 			idString = i18n("The certificate is invalid.");
-			idCode   = "InvalidCert";
+			idCode   = QStringLiteral("InvalidCert");
 			break;
 		case QCA::TLS::NoCertificate:
 			idString = i18n("No certificate was presented.");
-			idCode   = "NoCert";
+			idCode   = QStringLiteral("NoCert");
 			break;
 	}
 
@@ -752,47 +751,47 @@ int GroupWiseAccount::handleTLSWarning ( QCA::TLS::IdentityResult identityResult
 			break;
 		case QCA::ErrorRejected:
 			validityString = i18n("The Certificate Authority rejected the certificate.");
-			code = "Rejected";
+			code = QStringLiteral("Rejected");
 			break;
 		case QCA::ErrorUntrusted:
 			validityString = i18n("The certificate is not trusted.");
-			code = "Untrusted";
+			code = QStringLiteral("Untrusted");
 			break;
 		case QCA::ErrorSignatureFailed:
 			validityString = i18n("The signature is invalid.");
-			code = "SignatureFailed";
+			code = QStringLiteral("SignatureFailed");
 			break;
 		case QCA::ErrorInvalidCA:
 			validityString = i18n("The Certificate Authority is invalid.");
-			code = "InvalidCA";
+			code = QStringLiteral("InvalidCA");
 			break;
 		case QCA::ErrorInvalidPurpose:
 			validityString = i18n("Invalid certificate purpose.");
-			code = "InvalidPurpose";
+			code = QStringLiteral("InvalidPurpose");
 			break;
 		case QCA::ErrorSelfSigned:
 			validityString = i18n("The certificate is self-signed.");
-			code = "SelfSigned";
+			code = QStringLiteral("SelfSigned");
 			break;
 		case QCA::ErrorRevoked:
 			validityString = i18n("The certificate has been revoked.");
-			code = "Revoked";
+			code = QStringLiteral("Revoked");
 			break;
 		case QCA::ErrorPathLengthExceeded:
 			validityString = i18n("Maximum certificate chain length was exceeded.");
-			code = "PathLengthExceeded";
+			code = QStringLiteral("PathLengthExceeded");
 			break;
 		case QCA::ErrorExpired:
 			validityString = i18n("The certificate has expired.");
-			code = "Expired";
+			code = QStringLiteral("Expired");
 			break;
 		case QCA::ErrorExpiredCA:
 			validityString = i18n("The Certificate Authority has expired.");
-			code = "ExpiredCA";
+			code = QStringLiteral("ExpiredCA");
 			break;
 		case QCA::ErrorValidityUnknown:
 			validityString = i18n("Validity is unknown.");
-			code = "ValidityUnknown";
+			code = QStringLiteral("ValidityUnknown");
 			break;
 	}
 
@@ -823,30 +822,30 @@ int GroupWiseAccount::handleTLSWarning ( QCA::TLS::IdentityResult identityResult
 					  i18n("GroupWise Connection Certificate Problem"),
 					  KStandardGuiItem::cont(),
 					  KStandardGuiItem::cancel(),
-					  QString("KopeteTLSWarning") + server + idCode + code) == KMessageBox::Continue );
+					  QStringLiteral("KopeteTLSWarning") + server + idCode + code) == KMessageBox::Continue );
 }
 
 void GroupWiseAccount::slotTLSReady( int secLayerCode )
 {
 	// i don't know what secLayerCode is for...
 	Q_UNUSED( secLayerCode );
-	kDebug() ;
+	qDebug() ;
 	m_client->start( server(), port(), accountId(), /*QLatin1String("bollax08")*/m_password );
 }
 
 void GroupWiseAccount::handleIncomingMessage( const ConferenceEvent & message )
 {
-	QString typeName = "UNKNOWN";
+	QString typeName = QStringLiteral("UNKNOWN");
 	if ( message.type == ReceiveMessage )
-		typeName = "message";
+		typeName = QStringLiteral("message");
 	else if ( message.type == ReceiveAutoReply )
-		typeName = "autoreply";
+		typeName = QStringLiteral("autoreply");
 	else if ( message.type == ReceivedBroadcast )
-		typeName = "broadcast";
+		typeName = QStringLiteral("broadcast");
 	else if ( message.type == ReceivedSystemBroadcast )
-		typeName = "system broadcast";
+		typeName = QStringLiteral("system broadcast");
 
-	kDebug() << " received a " <<  typeName << " from " << message.user << ", to conference: " << message.guid << ", message: " << message.message;
+	qDebug() << " received a " <<  typeName << " from " << message.user << ", to conference: " << message.guid << ", message: " << message.message;
 
 	GroupWiseContact * sender = contactForDN( message.user );
 	if ( !sender )
@@ -886,7 +885,7 @@ void GroupWiseAccount::handleIncomingMessage( const ConferenceEvent & message )
 		messageMunged = prefix + message.message;
 	}
 
-	kDebug() << " message before KopeteMessage and appending: " << messageMunged;
+	qDebug() << " message before KopeteMessage and appending: " << messageMunged;
 	Kopete::Message * newMessage = 
 			new Kopete::Message( sender, contactList );
 	newMessage->setTimestamp( message.timeStamp );
@@ -898,13 +897,13 @@ void GroupWiseAccount::handleIncomingMessage( const ConferenceEvent & message )
 	}
 	Q_ASSERT( sess );
 	sess->appendMessage( *newMessage );
-	kDebug() << "message from KopeteMessage: plainbody: " << newMessage->plainBody() << " parsedbody: " << newMessage->parsedBody();
+	qDebug() << "message from KopeteMessage: plainbody: " << newMessage->plainBody() << " parsedbody: " << newMessage->parsedBody();
 	delete newMessage;
 }
 
 void GroupWiseAccount::receiveFolder( const FolderItem & folder )
 {
-	kDebug() 
+	qDebug() 
 			<< " objectId: " << folder.id
 			<< " sequence: " << folder.sequence
 			<< " parentId: " << folder.parentId
@@ -948,7 +947,7 @@ void GroupWiseAccount::receiveFolder( const FolderItem & folder )
 
 	if ( !found )
 	{
-		kDebug() << " - not found locally, creating Kopete::Group";
+		qDebug() << " - not found locally, creating Kopete::Group";
 		Kopete::Group * grp = new Kopete::Group( folder.name );
 		grp->setPluginData( protocol(), accountId() + " serverDisplayName", folder.name );
 		grp->setPluginData( protocol(), accountId() + " objectId", QString::number( folder.id ) );
@@ -958,13 +957,13 @@ void GroupWiseAccount::receiveFolder( const FolderItem & folder )
 
 void GroupWiseAccount::receiveContact( const ContactItem & contact )
 {
-	kDebug() 
+	qDebug() 
 			<< " objectId: " << contact.id
 			<< ", sequence: " << contact.sequence
 			<< ", parentId: " << contact.parentId
 			<< ", dn: " << contact.dn
 			<< ", displayName: " << contact.displayName << endl;
-	//kDebug() << "\n dotted notation is '" << protocol()->dnToDotted( contact.dn ) << "'\n";
+	//qDebug() << "\n dotted notation is '" << protocol()->dnToDotted( contact.dn ) << "'\n";
 
 	// add to new style contact list
 	GWContactInstance * gwInst = m_serverListModel->addContactInstance( contact.id, contact.parentId, contact.sequence, contact.displayName, contact.dn );
@@ -989,7 +988,7 @@ void GroupWiseAccount::receiveContact( const ContactItem & contact )
 		GWFolder * folder = m_serverListModel->findFolderById( contact.parentId );
 		if ( !folder ) // inconsistent
 		{
-			kDebug() << " - ERROR - contact's folder doesn't exist on server";
+			qDebug() << " - ERROR - contact's folder doesn't exist on server";
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
 			dit->item( contact.parentId, contact.id );
 //			QObject::connect( dit, SIGNAL(gotContactDeleted(ContactItem)), SLOT(receiveContactDeleted(ContactItem)) );
@@ -1000,7 +999,7 @@ void GroupWiseAccount::receiveContact( const ContactItem & contact )
 		// grp should exist, because we receive the folders from the server before the contacts
 		if ( grp )
 		{
-			kDebug() << " - making sure MC is in group " << grp->displayName();
+			qDebug() << " - making sure MC is in group " << grp->displayName();
 			m_dontSync = true;
 			c->metaContact()->addToGroup( grp ); //addToGroup() is safe to call if already a member
 			m_dontSync = false;
@@ -1013,7 +1012,7 @@ void GroupWiseAccount::receiveContact( const ContactItem & contact )
 
 void GroupWiseAccount::receiveAccountDetails( const ContactDetails & details )
 {
-	kDebug() 
+	qDebug() 
 		<< "Auth attribute: " << details.authAttribute
 		<< ", Away message: " << details.awayMessage
 		<< ", CN" << details.cn
@@ -1025,7 +1024,7 @@ void GroupWiseAccount::receiveAccountDetails( const ContactDetails & details )
 		<< endl;
 	if ( details.cn.toLower() == accountId().toLower().section('@', 0, 0) ) // incase user set account ID foo@novell.com
 	{
-		kDebug() << " - got our details in contact list, updating them";
+		qDebug() << " - got our details in contact list, updating them";
 		GroupWiseContact * detailsOwner= static_cast<GroupWiseContact *>( myself() );
 		detailsOwner->updateDetails( details );
 		//detailsOwner->setProperty( Kopete::Global::Properties::self()->nickName(), details.fullName );
@@ -1037,13 +1036,13 @@ void GroupWiseAccount::receiveAccountDetails( const ContactDetails & details )
 	}
 	else
 	{
-		kDebug() << " - passed someone else's details in contact list!";
+		qDebug() << " - passed someone else's details in contact list!";
 	}
 }
 
 void GroupWiseAccount::receiveContactUserDetails( const ContactDetails & details )
 {
-	kDebug() 
+	qDebug() 
 		<< "Auth attribute: " << details.authAttribute
 		<< ", Away message: " << details.awayMessage
 		<< ", CN" << details.cn
@@ -1061,12 +1060,12 @@ void GroupWiseAccount::receiveContactUserDetails( const ContactDetails & details
 
 		if( detailsOwner )
 		{
-			kDebug() << " - updating details for " << details.dn;
+			qDebug() << " - updating details for " << details.dn;
 			detailsOwner->updateDetails( details );
 		}
 		else
 		{
-			kDebug() << " - got details for " << details.dn << ", but they aren't in our contact list!";
+			qDebug() << " - got details for " << details.dn << ", but they aren't in our contact list!";
 		}
 	}
 }
@@ -1077,8 +1076,8 @@ GroupWiseContact * GroupWiseAccount::createTemporaryContact( const QString & dn
 	GroupWiseContact * c = static_cast<GroupWiseContact *>( contacts().value(details.dn.toLower() ));
 	if ( !c && ( details.dn != accountId() ) )
 	{
-		kDebug() << "Got a temporary contact DN: " << details.dn;
-		kDebug() 
+		qDebug() << "Got a temporary contact DN: " << details.dn;
+		qDebug() 
 		<< "  Auth attribute: " << details.authAttribute
 		<< "  , Away message: " << details.awayMessage
 		<< "  , CN" << details.cn
@@ -1106,24 +1105,24 @@ GroupWiseContact * GroupWiseAccount::createTemporaryContact( const QString & dn
 	}
 	else
 	{
-		kDebug() << "Notified of existing temporary contact DN: " << details.dn;
+		qDebug() << "Notified of existing temporary contact DN: " << details.dn;
 	}
 	return c;
 }
 
 void GroupWiseAccount::receiveStatus( const QString & contactId, quint16 status, const QString &awayMessage )
 {
-	kDebug() << "got status for: " << contactId << ", status: " << status << ", away message: " << awayMessage;
+	qDebug() << "got status for: " << contactId << ", status: " << status << ", away message: " << awayMessage;
 	GroupWiseContact * c = contactForDN( contactId );
 	if ( c )
 	{
-		kDebug() << " - their KOS is: " << protocol()->gwStatusToKOS( status ).description();
+		qDebug() << " - their KOS is: " << protocol()->gwStatusToKOS( status ).description();
 		Kopete::OnlineStatus kos = protocol()->gwStatusToKOS( status );
 		c->setOnlineStatus( kos );
 		c->setStatusMessage( awayMessage );
 	}
 	else
-		kDebug() << " couldn't find " << contactId;
+		qDebug() << " couldn't find " << contactId;
 }
 
 void GroupWiseAccount::changeOurStatus( GroupWise::Status status, const QString & awayMessage, const QString & autoReply )
@@ -1173,12 +1172,12 @@ bool GroupWiseAccount::createContact( const QString& contactId, Kopete::MetaCont
 			continue;
 		}
 
-		kDebug() << "looking up: " << group->displayName();
+		qDebug() << "looking up: " << group->displayName();
 		GWFolder * fld = m_serverListModel->findFolderByName( group->displayName() );
 		FolderItem fi;
 		if ( fld )
 		{
-			kDebug() << fld->displayName;
+			qDebug() << fld->displayName;
 			//FIXME - get rid of FolderItem & co
 			fi.parentId = qobject_cast<GWFolder*>( fld->parent() )->id;
 			fi.id = fld->id;
@@ -1186,7 +1185,7 @@ bool GroupWiseAccount::createContact( const QString& contactId, Kopete::MetaCont
 		}
 		else
 		{
-			kDebug() << "folder: " << group->displayName() << 
+			qDebug() << "folder: " << group->displayName() << 
 				"not found in server list model." << endl;
 			fi.parentId = 0;
 			fi.id = 0;
@@ -1220,7 +1219,7 @@ bool GroupWiseAccount::createContact( const QString& contactId, Kopete::MetaCont
 
 	if ( folders.isEmpty() && !topLevel )
 	{
-		kDebug() << "aborting because we didn't find any groups to add them to";
+		qDebug() << "aborting because we didn't find any groups to add them to";
 		return false;
 	}
 	
@@ -1234,7 +1233,7 @@ bool GroupWiseAccount::createContact( const QString& contactId, Kopete::MetaCont
 
 void GroupWiseAccount::receiveContactCreated()
 {
-	kDebug() ;
+	qDebug() ;
 	m_serverListModel->dump();
 
 	CreateContactTask * cct = ( CreateContactTask * )sender();
@@ -1271,7 +1270,7 @@ void GroupWiseAccount::receiveContactCreated()
 					delete c;
 			}
 		}
-		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget (), KMessageBox::Error,
+		KMessageBox::error( Kopete::UI::Global::mainWidget (),
 							i18n ("The contact %1 could not be added to the contact list, with error message: %2", 
 							cct->userId(), cct->statusString() ),
 							i18n ("Error Adding Contact") );
@@ -1280,7 +1279,7 @@ void GroupWiseAccount::receiveContactCreated()
 
 void GroupWiseAccount::deleteContact( GroupWiseContact * contact )
 {
-	kDebug() ;
+	qDebug() ;
 	contact->setDeleting( true );
 	if ( isConnected() )
 	{
@@ -1299,7 +1298,7 @@ void GroupWiseAccount::deleteContact( GroupWiseContact * contact )
 
 void GroupWiseAccount::receiveContactDeleted( const ContactItem & instance )
 {
-	kDebug() ;
+	qDebug() ;
 	// an instance of this contact was deleted on the server.
 	// Remove it from the model of the server side list,
 	// and if there are no other instances of this contact, delete the contact
@@ -1307,7 +1306,7 @@ void GroupWiseAccount::receiveContactDeleted( const ContactItem & instance )
 	m_serverListModel->dump();
 
 	GWContactInstanceList instances = m_serverListModel->instancesWithDn( instance.dn );
-	kDebug() << " - " << instance.dn << " now has " << instances.count() << " instances remaining.";
+	qDebug() << " - " << instance.dn << " now has " << instances.count() << " instances remaining.";
 	GroupWiseContact * c = contactForDN( instance.dn );
 	if ( c && instances.count() == 0 && c->deleting() )
 	{
@@ -1315,7 +1314,6 @@ void GroupWiseAccount::receiveContactDeleted( const ContactItem & instance )
 	}
 }
 
-
 void GroupWiseAccount::slotConnectedElsewhere()
 {
 	if ( !isBusy() )
@@ -1351,7 +1349,7 @@ void GroupWiseAccount::receiveConferenceJoin( const GroupWise::ConferenceGuid &
 	QStringListIterator joinerIt( participants );
 	while ( joinerIt.hasNext() )
 	{
-		//kDebug() << " adding participant " << *it;
+		//qDebug() << " adding participant " << *it;
 		QString dn = joinerIt.next();
 		GroupWiseContact * c = contactForDN( dn );
 		if ( !c )
@@ -1362,7 +1360,7 @@ void GroupWiseAccount::receiveConferenceJoin( const GroupWise::ConferenceGuid &
 	QStringListIterator inviteeIt( invitees );
 	while ( inviteeIt.hasNext() )
 	{
-		//kDebug() << " adding invitee " << *it;
+		//qDebug() << " adding invitee " << *it;
 		QString dn = inviteeIt.next();
 		GroupWiseContact * c = contactForDN( dn );
 		if ( !c )
@@ -1374,7 +1372,7 @@ void GroupWiseAccount::receiveConferenceJoin( const GroupWise::ConferenceGuid &
 
 void GroupWiseAccount::receiveConferenceJoinNotify( const ConferenceEvent & event )
 {
-	kDebug() ;
+	qDebug() ;
 	GroupWiseChatSession * sess = findChatSessionByGuid( event.guid );
 	if ( sess )
 	{
@@ -1384,12 +1382,12 @@ void GroupWiseAccount::receiveConferenceJoinNotify( const ConferenceEvent & even
 		sess->joined( c );
 	}
 	else
-		kDebug() << " couldn't find a GWCS for conference: " << event.guid;
+		qDebug() << " couldn't find a GWCS for conference: " << event.guid;
 }
 
 void GroupWiseAccount::receiveConferenceLeft( const ConferenceEvent & event )
 {
-	kDebug() ;
+	qDebug() ;
 	GroupWiseChatSession * sess = findChatSessionByGuid( event.guid );
 	if ( sess )
 	{
@@ -1399,16 +1397,16 @@ void GroupWiseAccount::receiveConferenceLeft( const ConferenceEvent & event )
 			sess->left( c );
 		}
 		else
-			kDebug() << " couldn't find a contact for DN: " << event.user;
+			qDebug() << " couldn't find a contact for DN: " << event.user;
 	}
 	else
-		kDebug() << " couldn't find a GWCS for conference: " << event.guid;
+		qDebug() << " couldn't find a GWCS for conference: " << event.guid;
 
 }
 	
 void GroupWiseAccount::receiveInviteDeclined( const ConferenceEvent & event )
 {
-	kDebug() ;
+	qDebug() ;
 	GroupWiseChatSession * sess = findChatSessionByGuid( event.guid );
 	if ( sess )
 	{
@@ -1417,12 +1415,12 @@ void GroupWiseAccount::receiveInviteDeclined( const ConferenceEvent & event )
 			sess->inviteDeclined( c );
 	}
 	else
-		kDebug() << " couldn't find a GWCS for conference: " << event.guid;
+		qDebug() << " couldn't find a GWCS for conference: " << event.guid;
 }
 
 void GroupWiseAccount::receiveInviteNotify( const ConferenceEvent & event )
 {
-	kDebug() ;
+	qDebug() ;
 	GroupWiseChatSession * sess = findChatSessionByGuid( event.guid );
 	if ( sess )
 	{
@@ -1436,16 +1434,16 @@ void GroupWiseAccount::receiveInviteNotify( const ConferenceEvent & event )
 		sess->appendMessage( declined );
 	}
 	else
-		kDebug() << " couldn't find a GWCS for conference: " << event.guid;
+		qDebug() << " couldn't find a GWCS for conference: " << event.guid;
 }
 
 void GroupWiseAccount::slotLeavingConference( GroupWiseChatSession * sess )
 {
-	kDebug() << "unregistering message manager:" << sess->guid();
+	qDebug() << "unregistering message manager:" << sess->guid();
 	if( isConnected () )
 		m_client->leaveConference( sess->guid() );
 	m_chatSessions.removeAll( sess );
-	kDebug() << "m_chatSessions now contains:" << m_chatSessions.count() << " managers";
+	qDebug() << "m_chatSessions now contains:" << m_chatSessions.count() << " managers";
 	Kopete::ContactPtrList members = sess->members();
 	foreach( Kopete::Contact * contact, members )
 	{
@@ -1456,11 +1454,9 @@ void GroupWiseAccount::slotLeavingConference( GroupWiseChatSession * sess )
 void GroupWiseAccount::slotSetAutoReply()
 {
 	bool ok;
-	QRegExp rx( ".*" );
-    QRegExpValidator validator( rx, this );
-	QString newAutoReply = KInputDialog::getText( i18n( "Enter Auto-Reply Message" ),
-			 i18n( "Please enter an Auto-Reply message that will be shown to users who message you while Away or Busy" ), configGroup()->readEntry( "AutoReply", "" ),
-			 &ok, Kopete::UI::Global::mainWidget(), &validator );
+    QString newAutoReply = QInputDialog::getText(Kopete::UI::Global::mainWidget(), i18n( "Enter Auto-Reply Message" ),
+             i18n( "Please enter an Auto-Reply message that will be shown to users who message you while Away or Busy" ), QLineEdit::Normal, configGroup()->readEntry( "AutoReply", "" ),
+             &ok);
 	if ( ok )
 		configGroup()->writeEntry( "AutoReply", newAutoReply );
 }
@@ -1471,14 +1467,14 @@ void GroupWiseAccount::slotTestRTFize()
 	const QString query = QString::fromLatin1("Enter a string to rtfize:");
 	QString testText = KLineEditDlg::getText( query, QString(), &ok, Kopete::UI::Global::mainWidget() );
 	if ( ok )
-		kDebug() << "Converted text is: '" << protocol()->rtfizeText( testText ) << "'";*/
+		qDebug() << "Converted text is: '" << protocol()->rtfizeText( testText ) << "'";*/
 
 // 	bool ok;
 // 	const QString query = i18n("Enter a contactId:");
 // 	QString testText = KInputDialog::getText( query, i18n("This is a test dialog and will not be in the final product!" ), QString(), &ok, Kopete::UI::Global::mainWidget() );
 // 	if ( !ok )
 // 		return;
-// 	kDebug() << "Trying to add contact: '" << protocol()->rtfizeText( testText ) << "'";
+// 	qDebug() << "Trying to add contact: '" << protocol()->rtfizeText( testText ) << "'";
 // 	Kopete::MetaContact *metaContact = new Kopete::MetaContact ();
 // 	metaContact->setDisplayName( "Test Add MC" );
 // 	metaContact->setTemporary (true);
@@ -1505,11 +1501,11 @@ bool GroupWiseAccount::isContactBlocked( const QString & dn )
 
 void GroupWiseAccount::dumpManagers()
 {
-	kDebug() << " for: " << accountId()
+	qDebug() << " for: " << accountId()
 		<< " containing: " << m_chatSessions.count() << " managers " << endl;
 	QList<GroupWiseChatSession *>::ConstIterator it;
 	for ( it = m_chatSessions.constBegin() ; it != m_chatSessions.constEnd(); ++it )
-		kDebug() << "guid: " << (*it)->guid();
+		qDebug() << "guid: " << (*it)->guid();
 }
 
 bool GroupWiseAccount::dontSync()
@@ -1524,10 +1520,10 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 	
 	if ( contact != myself() )
 	{
-		kDebug() ;
+		qDebug() ;
 		if ( !isConnected() )
 		{
-			kDebug() << "not connected, can't sync display name or group membership";
+			qDebug() << "not connected, can't sync display name or group membership";
 			return;
 		}
 	
@@ -1535,9 +1531,9 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 		if ( contact->metaContact()->isTemporary() )
 			return;
 
-		kDebug() << " = CONTACT '" << contact->nickName() << "' IS IN " << contact->metaContact()->groups().count() << " MC GROUPS, AND HAS " << m_serverListModel->instancesWithDn( contact->dn() ).count() << " CONTACT LIST INSTANCES.";
+		qDebug() << " = CONTACT '" << contact->nickName() << "' IS IN " << contact->metaContact()->groups().count() << " MC GROUPS, AND HAS " << m_serverListModel->instancesWithDn( contact->dn() ).count() << " CONTACT LIST INSTANCES.";
 
-		kDebug() << " = LOOKING FOR NOOP GROUP MEMBERSHIPS";
+		qDebug() << " = LOOKING FOR NOOP GROUP MEMBERSHIPS";
 		// 1) Seek matches between CLIs and MCGs and remove from the lists without taking any action. match on objectid, parentid
 		// 2) Each remaining unmatched pair is a move, initiate and remove - need to take care to always use greatest unused sequence number - if we have to set the sequence number to the following sequence number within the folder, we may have a problem where after the first move, we have to wait for the state of the CLIs to be updated pending the completion of the first move - this would be difficult to cope with, because our current lists would be out of date, or we'd have to restart the sync - assuming the first move created a new matched CLI-MCG pair, we could do that with little cost.
 		// 3) Any remaining entries in MCG list are adds, carry out
@@ -1564,7 +1560,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			{
 				instIt.next();
 				GWFolder * folder = qobject_cast<GWFolder *>( instIt.value()->parent() );
-				kDebug() << "  - Looking for a match, MC grp '" 
+				qDebug() << "  - Looking for a match, MC grp '" 
 					<< grpIt.value()->displayName()
 					<< "', GWFolder '" << folder->displayName << "', objectId is " << folder->id << endl;
 				
@@ -1572,7 +1568,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 						|| ( grpIt.value()->displayName() == folder->displayName ) )
 				{
 					//this pair matches, we can remove its members from both lists )
-					kDebug() << "  - match! removing both entries";
+					qDebug() << "  - match! removing both entries";
 					instIt.remove();
 					grpIt.remove();
 					break;
@@ -1580,7 +1576,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			}
 		}
 		
-		kDebug() << " = LOOKING FOR UNMATCHED PAIRS => GROUP MOVES";
+		qDebug() << " = LOOKING FOR UNMATCHED PAIRS => GROUP MOVES";
 		grpIt.toFront();
 		// ( take the first pair and carry out a move )
 		while ( grpIt.hasNext() && !instances.isEmpty() )
@@ -1588,7 +1584,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			grpIt.next();
 			GWContactInstance * cliInstance = instances.takeFirst();
 			GWFolder * sourceFolder = qobject_cast<GWFolder*>( cliInstance->parent() );
-			kDebug() << "  - moving contact instance from group '" << sourceFolder->displayName << "' to group '" << grpIt.value()->displayName() << "'";
+			qDebug() << "  - moving contact instance from group '" << sourceFolder->displayName << "' to group '" << grpIt.value()->displayName() << "'";
 
 			// create contactItem parameter
 			ContactItem instance;
@@ -1626,7 +1622,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			grpIt.remove();
 		}
 
-		kDebug() << " = LOOKING FOR ADDS";
+		qDebug() << " = LOOKING FOR ADDS";
 		grpIt.toFront();
 		while ( grpIt.hasNext() )
 		{
@@ -1655,14 +1651,14 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			grpIt.remove();
 		}
 
-		kDebug() << " = LOOKING FOR REMOVES";
+		qDebug() << " = LOOKING FOR REMOVES";
 		QMutableListIterator<GWContactInstance *>  instIt( instances );
 		// ( remove each remaining contact list instance, because it doesn't exist locally any more )
 		while ( instIt.hasNext() )
 		{
 			instIt.next();
 			GWFolder * folder =qobject_cast<GWFolder*>( ( instIt.value() )->parent() );
-			kDebug() << "  - remove contact instance '"<< ( instIt.value() )->id << "' in group '" << folder->displayName << "'";
+			qDebug() << "  - remove contact instance '"<< ( instIt.value() )->id << "' in group '" << folder->displayName << "'";
 
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
 			dit->item( folder->id, instIt.value()->id );
@@ -1675,7 +1671,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 		// start an UpdateItem
 		if ( contact->metaContact()->displayName() != contact->nickName() )
 		{
-			kDebug() << " updating the contact's display name to the metacontact's: " << contact->metaContact()->displayName();
+			qDebug() << " updating the contact's display name to the metacontact's: " << contact->metaContact()->displayName();
 			foreach ( GWContactInstance * instance, m_serverListModel->instancesWithDn( contact->dn() ) )
 			{
 				QList< ContactItem > instancesToChange;
@@ -1696,4 +1692,3 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 	}
 }
 
-#include "gwaccount.moc"
