@@ -25,13 +25,13 @@
 #include <QByteArray>
 #include <stdlib.h>
 #include <qca.h>
+
 #include "xmpp_xmlcommon.h"
 #include "im.h"
 #include "socks.h"
 #include "safedelete.h"
 
 #ifdef Q_OS_WIN
-# include <winsock2.h>
 # include <windows.h>
 #else
 # include <netinet/in.h>
@@ -829,7 +829,7 @@ void S5BManager::srv_incomingReady(SocksClient *sc, const QString &key)
 	Entry *e = findEntryByHash(key);
 	if(!e->i->allowIncoming) {
 		sc->requestDeny();
-		SafeDelete::deleteSingle(sc);
+		sc->deleteLater();
 		return;
 	}
 	if(e->c->d->mode == S5BConnection::Datagram)
@@ -843,7 +843,7 @@ void S5BManager::srv_incomingReady(SocksClient *sc, const QString &key)
 void S5BManager::srv_incomingUDP(bool init, const QHostAddress &addr, int port, const QString &key, const QByteArray &data)
 {
 	Entry *e = findEntryByHash(key);
-	if(!e->c->d->mode != S5BConnection::Datagram)
+	if(e->c->d->mode != S5BConnection::Datagram)
 		return; // this key isn't in udp mode?  drop!
 
 	if(init) {
@@ -2105,7 +2105,7 @@ void S5BServer::ss_incomingReady()
 
 void S5BServer::ss_incomingUDP(const QString &host, int port, const QHostAddress &addr, int sourcePort, const QByteArray &data)
 {
-	if(port != 0 || port != 1)
+	if(port != 0 && port != 1)
 		return;
 
 	foreach(S5BManager* m, d->manList) {
